# Dialog

User-friendly API for console-based user interaction.

## Installation

Install the package through `pip`:

```bash
pip install avanserv-dialog
```

## Usage

Import the console object and start using it.

```python
from dialog import console


console.info("Hello world!")
```
